@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2019 Jeffrey Stedfast
+ *  Copyright (C) 2000-2020 Jeffrey Stedfast
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -556,12 +556,33 @@ g_mime_certificate_get_created (GMimeCertificate *cert)
 }
 
 
+/**
+ * g_mime_certificate_get_created64:
+ * @cert: a #GMimeCertificate
+ *
+ * Get the creation date of the certificate's key in seconds since the
+ * UNIX epoch, represented as a 64-bit signed integer.
+ *
+ * Returns: the creation date of the certificate's key or %-1 if unknown.
+ **/
+gint64
+g_mime_certificate_get_created64 (GMimeCertificate *cert)
+{
+	g_return_val_if_fail (GMIME_IS_CERTIFICATE (cert), -1);
+	
+	if (cert->created == (time_t) -1)
+		return -1;
+	
+	return (gint64) ((unsigned long) cert->created);
+}
+
+
 /**
  * g_mime_certificate_set_expires:
  * @cert: a #GMimeCertificate
  * @expires: expiration date
  *
- * Set the expiration date of the certificate's key.
+ * Set the expiration date of the certificate's key. A value of %0 means the certificate never expires.
  **/
 void
 g_mime_certificate_set_expires (GMimeCertificate *cert, time_t expires)
@@ -576,7 +597,7 @@ g_mime_certificate_set_expires (GMimeCertificate *cert, time_t expires)
  * g_mime_certificate_get_expires:
  * @cert: a #GMimeCertificate
  *
- * Get the expiration date of the certificate's key.
+ * Get the expiration date of the certificate's key. A value of %0 means the certificate never expires.
  *
  * Returns: the expiration date of the certificate's key or %-1 if unknown.
  **/
@@ -589,6 +610,28 @@ g_mime_certificate_get_expires (GMimeCertificate *cert)
 }
 
 
+/**
+ * g_mime_certificate_get_expires64:
+ * @cert: a #GMimeCertificate
+ *
+ * Get the expiration date of the certificate's key in seconds since
+ * the UNIX epoch, represented as a 64-bit signed integer. A value of
+ * %0 means the certificate never expires.
+ *
+ * Returns: the expiration date of the certificate's key or %-1 if unknown.
+ **/
+gint64
+g_mime_certificate_get_expires64 (GMimeCertificate *cert)
+{
+	g_return_val_if_fail (GMIME_IS_CERTIFICATE (cert), -1);
+	
+	if (cert->expires == (time_t) -1)
+		return -1;
+	
+	return (gint64) ((unsigned long) cert->expires);
+}
+
+
 static void g_mime_certificate_list_class_init (GMimeCertificateListClass *klass);
 static void g_mime_certificate_list_init (GMimeCertificateList *list, GMimeCertificateListClass *klass);
 static void g_mime_certificate_list_finalize (GObject *object);
