@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2014 Jeffrey Stedfast
+ *  Copyright (C) 2000-2020 Jeffrey Stedfast
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -52,7 +52,7 @@ typedef struct _GMimeDecryptResultClass GMimeDecryptResultClass;
  * GMimePasswordRequestFunc:
  * @ctx: the #GMimeCryptoContext making the request
  * @user_id: the user_id of the password being requested
- * @prompt_ctx: a string containing some helpful context for the prompt
+ * @prompt: a string containing some helpful context for the prompt
  * @reprompt: %TRUE if this password request is a reprompt due to a previously bad password response
  * @response: a stream for the application to write the password to (followed by a newline '\n' character)
  * @err: a #GError for the callback to set if an error occurs
@@ -62,10 +62,75 @@ typedef struct _GMimeDecryptResultClass GMimeDecryptResultClass;
  *
  * Returns: %TRUE on success or %FALSE on error.
  **/
-typedef gboolean (* GMimePasswordRequestFunc) (GMimeCryptoContext *ctx, const char *user_id, const char *prompt_ctx,
+typedef gboolean (* GMimePasswordRequestFunc) (GMimeCryptoContext *ctx, const char *user_id, const char *prompt,
 					       gboolean reprompt, GMimeStream *response, GError **err);
 
 
+/**
+ * GMimeCryptoContextNewFunc:
+ *
+ * A callback used to create a new instance of a #GMimeCryptoContext subclass.
+ *
+ * Returns: a new #GMimeCryptoContext instance.
+ **/
+typedef GMimeCryptoContext * (* GMimeCryptoContextNewFunc) (void);
+
+
+/**
+ * GMimeDecryptFlags:
+ * @GMIME_DECRYPT_NONE: No flags specified.
+ * @GMIME_DECRYPT_EXPORT_SESSION_KEY: Export the decryption session-key.
+ * @GMIME_DECRYPT_NO_VERIFY: Disable signature verification.
+ * @GMIME_DECRYPT_ENABLE_KEYSERVER_LOOKUPS: Enable OpenPGP keyserver lookups.
+ * @GMIME_DECRYPT_ENABLE_ONLINE_CERTIFICATE_CHECKS: Enable CRL and OCSP checks that require network lookups.
+ *
+ * Decryption flags.
+ **/
+typedef enum {
+	GMIME_DECRYPT_NONE                             = 0,
+	GMIME_DECRYPT_EXPORT_SESSION_KEY               = 1 << 0,
+	GMIME_DECRYPT_NO_VERIFY                        = 1 << 1,
+
+	/* Note: these values must stay in sync with GMimeVerifyFlags */
+	GMIME_DECRYPT_ENABLE_KEYSERVER_LOOKUPS         = 1 << 15,
+	GMIME_DECRYPT_ENABLE_ONLINE_CERTIFICATE_CHECKS = 1 << 15
+} GMimeDecryptFlags;
+
+
+/**
+ * GMimeEncryptFlags:
+ * @GMIME_ENCRYPT_NONE: No flags specified.
+ * @GMIME_ENCRYPT_ALWAYS_TRUST: Always trust the specified keys.
+ * @GMIME_ENCRYPT_NO_COMPRESS: Don't compress the plaintext before encrypting.
+ * @GMIME_ENCRYPT_SYMMETRIC: Encrypt symmetrically.
+ * @GMIME_ENCRYPT_THROW_KEYIDS: Do not include the key ids in the ciphertext.
+ *
+ * Encryption flags.
+ **/
+typedef enum {
+	GMIME_ENCRYPT_NONE          = 0,
+	GMIME_ENCRYPT_ALWAYS_TRUST  = 1,
+	GMIME_ENCRYPT_NO_COMPRESS   = 16,
+	GMIME_ENCRYPT_SYMMETRIC     = 32,
+	GMIME_ENCRYPT_THROW_KEYIDS  = 64,
+} GMimeEncryptFlags;
+
+
+/**
+ * GMimeVerifyFlags:
+ * @GMIME_VERIFY_NONE: No flags specified.
+ * @GMIME_VERIFY_ENABLE_KEYSERVER_LOOKUPS: Enable OpenPGP keyserver lookups.
+ * @GMIME_VERIFY_ENABLE_ONLINE_CERTIFICATE_CHECKS: Enable CRL and OCSP checks that require network lookups.
+ *
+ * Signature verification flags.
+ **/
+typedef enum {
+	GMIME_VERIFY_NONE                             = 0,
+	GMIME_VERIFY_ENABLE_KEYSERVER_LOOKUPS         = 1 << 15,
+	GMIME_VERIFY_ENABLE_ONLINE_CERTIFICATE_CHECKS = 1 << 15
+} GMimeVerifyFlags;
+
+
 /**
  * GMimeCryptoContext:
  * @parent_object: parent #GObject
@@ -83,80 +148,85 @@ struct _GMimeCryptoContextClass {
 	GObjectClass parent_class;
 	
 	GMimeDigestAlgo          (* digest_id)   (GMimeCryptoContext *ctx, const char *name);
-	
 	const char *             (* digest_name) (GMimeCryptoContext *ctx, GMimeDigestAlgo digest);
 	
 	const char *             (* get_signature_protocol) (GMimeCryptoContext *ctx);
-	
 	const char *             (* get_encryption_protocol) (GMimeCryptoContext *ctx);
-	
 	const char *             (* get_key_exchange_protocol) (GMimeCryptoContext *ctx);
 	
-	int                      (* sign)        (GMimeCryptoContext *ctx, const char *userid,
-						  GMimeDigestAlgo digest, GMimeStream *istream,
+	int                      (* sign)        (GMimeCryptoContext *ctx, gboolean detach,
+						  const char *userid, GMimeStream *istream,
 						  GMimeStream *ostream, GError **err);
 	
-	GMimeSignatureList *     (* verify)      (GMimeCryptoContext *ctx, GMimeDigestAlgo digest,
+	GMimeSignatureList *     (* verify)      (GMimeCryptoContext *ctx, GMimeVerifyFlags flags,
 						  GMimeStream *istream, GMimeStream *sigstream,
-						  GError **err);
+						  GMimeStream *ostream, GError **err);
 	
 	int                      (* encrypt)     (GMimeCryptoContext *ctx, gboolean sign,
-						  const char *userid, GMimeDigestAlgo digest,
+						  const char *userid, GMimeEncryptFlags flags,
 						  GPtrArray *recipients, GMimeStream *istream,
 						  GMimeStream *ostream, GError **err);
 	
-	GMimeDecryptResult *     (* decrypt)     (GMimeCryptoContext *ctx, GMimeStream *istream,
+	GMimeDecryptResult *     (* decrypt)     (GMimeCryptoContext *ctx, GMimeDecryptFlags flags,
+						  const char *session_key, GMimeStream *istream,
 						  GMimeStream *ostream, GError **err);
 	
 	int                      (* import_keys) (GMimeCryptoContext *ctx, GMimeStream *istream,
 						  GError **err);
 	
-	int                      (* export_keys) (GMimeCryptoContext *ctx, GPtrArray *keys,
+	int                      (* export_keys) (GMimeCryptoContext *ctx, const char *keys[],
 						  GMimeStream *ostream, GError **err);
+
+#if 0
+	int                      (* compress)    (GMimeCryptoContext *ctx, GMimeStream *istream,
+						  GMimeStream *ostream, GError **err);
+
+	int                      (* decompress)  (GMimeCryptoContext *ctx, GMimeStream *istream,
+						  GMimeStream *ostream, GError **err);
+#endif
 };
 
 
 GType g_mime_crypto_context_get_type (void);
 
+void g_mime_crypto_context_register (const char *protocol, GMimeCryptoContextNewFunc callback);
+GMimeCryptoContext *g_mime_crypto_context_new (const char *protocol);
+
 void g_mime_crypto_context_set_request_password (GMimeCryptoContext *ctx, GMimePasswordRequestFunc request_passwd);
 
 /* digest algo mapping */
 GMimeDigestAlgo g_mime_crypto_context_digest_id (GMimeCryptoContext *ctx, const char *name);
-
 const char *g_mime_crypto_context_digest_name (GMimeCryptoContext *ctx, GMimeDigestAlgo digest);
 
 /* protocol routines */
 const char *g_mime_crypto_context_get_signature_protocol (GMimeCryptoContext *ctx);
-
 const char *g_mime_crypto_context_get_encryption_protocol (GMimeCryptoContext *ctx);
-
 const char *g_mime_crypto_context_get_key_exchange_protocol (GMimeCryptoContext *ctx);
 
 /* crypto routines */
-int g_mime_crypto_context_sign (GMimeCryptoContext *ctx, const char *userid,
-				GMimeDigestAlgo digest, GMimeStream *istream,
-				GMimeStream *ostream, GError **err);
+int g_mime_crypto_context_sign (GMimeCryptoContext *ctx, gboolean detach, const char *userid,
+				GMimeStream *istream, GMimeStream *ostream, GError **err);
 
-GMimeSignatureList *g_mime_crypto_context_verify (GMimeCryptoContext *ctx, GMimeDigestAlgo digest,
+GMimeSignatureList *g_mime_crypto_context_verify (GMimeCryptoContext *ctx, GMimeVerifyFlags flags,
 						  GMimeStream *istream, GMimeStream *sigstream,
-						  GError **err);
+						  GMimeStream *ostream, GError **err);
 
-int g_mime_crypto_context_encrypt (GMimeCryptoContext *ctx, gboolean sign,
-				   const char *userid, GMimeDigestAlgo digest,
-				   GPtrArray *recipients, GMimeStream *istream,
-				   GMimeStream *ostream, GError **err);
+int g_mime_crypto_context_encrypt (GMimeCryptoContext *ctx, gboolean sign, const char *userid,
+				   GMimeEncryptFlags flags, GPtrArray *recipients,
+				   GMimeStream *istream, GMimeStream *ostream,
+				   GError **err);
 
-GMimeDecryptResult *g_mime_crypto_context_decrypt (GMimeCryptoContext *ctx, GMimeStream *istream,
+GMimeDecryptResult *g_mime_crypto_context_decrypt (GMimeCryptoContext *ctx, GMimeDecryptFlags flags,
+						   const char *session_key, GMimeStream *istream,
 						   GMimeStream *ostream, GError **err);
 
 /* key/certificate routines */
 int g_mime_crypto_context_import_keys (GMimeCryptoContext *ctx, GMimeStream *istream, GError **err);
 
-int g_mime_crypto_context_export_keys (GMimeCryptoContext *ctx, GPtrArray *keys,
+int g_mime_crypto_context_export_keys (GMimeCryptoContext *ctx, const char *keys[],
 				       GMimeStream *ostream, GError **err);
 
 
-
 /**
  * GMimeCipherAlgo:
  * @GMIME_CIPHER_ALGO_DEFAULT: The default (or unknown) cipher.
@@ -196,6 +266,7 @@ typedef enum {
  * @signatures: A #GMimeSignatureList if signed or %NULL otherwise.
  * @cipher: The cipher algorithm used to encrypt the stream.
  * @mdc: The MDC digest algorithm used, if any.
+ * @session_key: The session key if requested or %NULL otherwise.
  *
  * An object containing the results from decrypting an encrypted stream.
  **/
@@ -206,6 +277,7 @@ struct _GMimeDecryptResult {
 	GMimeSignatureList *signatures;
 	GMimeCipherAlgo cipher;
 	GMimeDigestAlgo mdc;
+	char *session_key;
 };
 
 struct _GMimeDecryptResultClass {
@@ -229,6 +301,9 @@ GMimeCipherAlgo g_mime_decrypt_result_get_cipher (GMimeDecryptResult *result);
 void g_mime_decrypt_result_set_mdc (GMimeDecryptResult *result, GMimeDigestAlgo mdc);
 GMimeDigestAlgo g_mime_decrypt_result_get_mdc (GMimeDecryptResult *result);
 
+void g_mime_decrypt_result_set_session_key (GMimeDecryptResult *result, const char *session_key);
+const char *g_mime_decrypt_result_get_session_key (GMimeDecryptResult *result);
+
 G_END_DECLS
 
 #endif /* __GMIME_CRYPTO_CONTEXT_H__ */
