@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2012 Jeffrey Stedfast
+ *  Copyright (C) 2000-2020 Jeffrey Stedfast
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -64,13 +64,10 @@ GType g_mime_multipart_signed_get_type (void);
 
 GMimeMultipartSigned *g_mime_multipart_signed_new (void);
 
-int g_mime_multipart_signed_sign (GMimeMultipartSigned *mps, GMimeObject *content,
-				  GMimeCryptoContext *ctx, const char *userid,
-				  GMimeDigestAlgo digest, GError **err);
+GMimeMultipartSigned *g_mime_multipart_signed_sign (GMimeCryptoContext *ctx, GMimeObject *entity,
+						    const char *userid, GError **err);
 
-GMimeSignatureList *g_mime_multipart_signed_verify (GMimeMultipartSigned *mps,
-						    GMimeCryptoContext *ctx,
-						    GError **err);
+GMimeSignatureList *g_mime_multipart_signed_verify (GMimeMultipartSigned *mps, GMimeVerifyFlags flags, GError **err);
 
 G_END_DECLS
 
