@@ -382,6 +382,7 @@ GMimeCryptoContext *
 g_mime_pkcs7_context_new (void)
 {
 #ifdef ENABLE_CRYPTO
+	gpgme_keylist_mode_t keylist_mode;
 	GMimePkcs7Context *pkcs7;
 	gpgme_ctx_t ctx;
 	
@@ -397,6 +398,17 @@ g_mime_pkcs7_context_new (void)
 	gpgme_set_protocol (ctx, GPGME_PROTOCOL_CMS);
 	gpgme_set_textmode (ctx, FALSE);
 	gpgme_set_armor (ctx, FALSE);
+	
+	/* ensure that key listings are correctly validated, since we
+	   use user ID validity to determine what identity to report */
+	keylist_mode = gpgme_get_keylist_mode (ctx);
+	if (!(keylist_mode & GPGME_KEYLIST_MODE_VALIDATE)) {
+		if (gpgme_set_keylist_mode (ctx, keylist_mode | GPGME_KEYLIST_MODE_VALIDATE) != GPG_ERR_NO_ERROR) {
+			gpgme_release (ctx);
+			return NULL;
+		}
+	}
+	
 	pkcs7->ctx = ctx;
 	
 	return (GMimeCryptoContext *) pkcs7;
