@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2019 Jeffrey Stedfast
+ *  Copyright (C) 2000-2020 Jeffrey Stedfast
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -224,12 +224,33 @@ g_mime_signature_get_created (GMimeSignature *sig)
 }
 
 
+/**
+ * g_mime_signature_get_created64:
+ * @sig: a #GMimeSignature
+ *
+ * Get the creation date of the signature in seconds since the UNIX
+ * epoch, represented as a 64-bit signed integer.
+ *
+ * Returns: the creation date of the signature or %-1 if unknown.
+ **/
+gint64
+g_mime_signature_get_created64 (GMimeSignature *sig)
+{
+	g_return_val_if_fail (GMIME_IS_SIGNATURE (sig), -1);
+	
+	if (sig->created == (time_t) -1)
+		return -1;
+	
+	return (gint64) ((unsigned long) sig->created);
+}
+
+
 /**
  * g_mime_signature_set_expires:
  * @sig: a #GMimeSignature
  * @expires: expiration date
  *
- * Set the expiration date of the signature.
+ * Set the expiration date of the signature. A value of %0 means the signature never expires.
  **/
 void
 g_mime_signature_set_expires (GMimeSignature *sig, time_t expires)
@@ -244,7 +265,7 @@ g_mime_signature_set_expires (GMimeSignature *sig, time_t expires)
  * g_mime_signature_get_expires:
  * @sig: a #GMimeSignature
  *
- * Get the expiration date of the signature.
+ * Get the expiration date of the signature. A value of %0 means the signature never expires.
  *
  * Returns: the expiration date of the signature or %-1 if unknown.
  **/
@@ -257,6 +278,28 @@ g_mime_signature_get_expires (GMimeSignature *sig)
 }
 
 
+/**
+ * g_mime_signature_get_expires64:
+ * @sig: a #GMimeSignature
+ *
+ * Get the expiration date of the signature in seconds since the UNIX
+ * epoch, represented as a 64-bit signed integer. A value of %0 means
+ * the signature never expires.
+ *
+ * Returns: the expiration date of the signature or %-1 if unknown.
+ **/
+gint64
+g_mime_signature_get_expires64 (GMimeSignature *sig)
+{
+	g_return_val_if_fail (GMIME_IS_SIGNATURE (sig), -1);
+	
+	if (sig->expires == (time_t) -1)
+		return -1;
+	
+	return (gint64) ((unsigned long) sig->expires);
+}
+
+
 static void g_mime_signature_list_class_init (GMimeSignatureListClass *klass);
 static void g_mime_signature_list_init (GMimeSignatureList *list, GMimeSignatureListClass *klass);
 static void g_mime_signature_list_finalize (GObject *object);
