@@ -33,114 +33,42 @@
 /*#define ENABLE_ZENTIMER*/
 #include "zentimer.h"
 
-#ifdef TEST_CACHE
-static char *charsets[] = {
-	"iso-8859-1",
-	"iso-8859-2",
-	"iso-8859-4",
-	"iso-8859-5",
-	"iso-8859-7",
-	"iso-8859-8",
-	"iso-8859-9",
-	"iso-8859-13",
-	"iso-8859-15",
-	"koi8-r",
-	"koi8-u",
-	"windows-1250",
-	"windows-1251",
-	"windows-1252",
-	"windows-1253",
-	"windows-1254",
-	"windows-1255",
-	"windows-1256",
-	"windows-1257",
-	"euc-kr",
-	"euc-jp",
-	"iso-2022-kr",
-	"iso-2022-jp",
-	"utf-8",
-};
-
-static void
-test_cache (void)
-{
-	GSList *node, *next, *open_cds = NULL;
-	iconv_t cd;
-	int i;
-	
-	srand (time (NULL));
-	
-	for (i = 0; i < 5000; i++) {
-		const char *from, *to;
-		int which;
-		
-		which = rand () % G_N_ELEMENTS (charsets);
-		from = charsets[which];
-		which = rand () % G_N_ELEMENTS (charsets);
-		to = charsets[which];
-		
-		cd = g_mime_iconv_open (from, to);
-		if (cd == (iconv_t) -1) {
-			g_warning ("%d: failed to open converter for %s to %s",
-				   i, from, to);
-			continue;
-		}
-		
-		which = rand () % 3;
-		if (!which) {
-			g_mime_iconv_close (cd);
-		} else {
-			open_cds = g_slist_prepend (open_cds, cd);
-		}
-	}
-	
-	node = open_cds;
-	while (node) {
-		next = node->next;
-		cd = node->data;
-		g_mime_iconv_close (cd);
-		g_slist_free_1 (node);
-		node = next;
-	}
-}
-#endif /* TEST_CACHE */
-
 
 struct {
 	const char *text;
 	const char *charset;
 } tests[] = {
-	{ "Ətraflı", "utf-8" },                /* az */
-	{ " ", "windows-cp1251" },      /* bg */
-	{ "Cnjuge", "iso-8859-1" },                /* ca */
-	{ "Avanceret sgning", "iso-8859-1" },      /* da */
-	{ "Lschen", "iso-8859-1" },                /* de */
-	{ "some text", "iso-8859-1" },              /* en */
-	{ "piv", "iso-8859-15" },                /* fi */
-	{ "Modifi", "iso-8859-1" },                /* fr */
-	{ "Tidal", "iso-8859-1" },                 /* ga */
-	{ "Fbrica", "iso-8859-1" },                /* gl */
-	{ "Szem-Blyhv-A ", "iso-8859-2" },            /* hu */
-	{ "Non c' corrispondenza", "iso-8859-1" }, /* it */
-	{ "$(B>e5i8!:w(B", "euc-jp" },                   /* ja */
-	{ "$(C0m1^(B $(C0K;v(B", "euc-kr" },                  /* ko */
-	{ "Isami paieka", "iso-8859-13" },        /* lt */
-	{ "Paplaint Meklana", "iso-8859-13" }, /* lv */
-	{ "Kopiren", "iso-8859-15" },              /* nl */
-	{ "ydelagd Sk", "iso-8859-1" },           /* nn */
-	{ "Avansert sk", "iso-8859-1" },           /* no */
-	{ "-Brda-A ksi-Bki-A adresowej", "iso-8859-2" }, /* pl */
-	{ "C-Butare-A avansat-B-A ", "iso-8859-2" },      /* ro */
-	{ "-L-A -L-A ", "koi8-r" },         /* ru */
-	{ "Pokročilé hľadanie", "utf-8" },    /* sk */
-	{ "Ga želite", "utf-8" },                  /* sl */
-	{ "den nd?", "iso-8859-1" },              /* sv */
-	{ "Geli-Mmi-A Arama", "iso-8859-9" },         /* tr */
-	{ " ", "koi8-u" },        /* uk */
+	{ "\xc6\x8ftrafl\xc4\xb1", "utf-8" },                                                      /* az */
+	{ "\xc4\xee\xe1\xe0\xe2\xe8 \xd3\xf1\xeb\xf3\xe3\xe0", "windows-cp1251" },                 /* bg */
+	{ "C\xf2njuge", "iso-8859-1" },                                                            /* ca */
+	{ "Avanceret s\xf8gning", "iso-8859-1" },                                                  /* da */
+	{ "L\xf6schen", "iso-8859-1" },                                                            /* de */
+	{ "some text", "iso-8859-1" },                                                             /* en */
+	{ "p\xe4iv\xe4\xe4", "iso-8859-15" },                                                      /* fi */
+	{ "Modifi\xe9", "iso-8859-1" },                                                            /* fr */
+	{ "Tid\xe9""al", "iso-8859-1" },                                                           /* ga */
+	{ "F\xe1""brica", "iso-8859-1" },                                                          /* gl */
+	{ "Szem\x1b-B\xe9lyh\xedv\xf3\x1b-A ", "iso-8859-2" },                                     /* hu */
+	{ "Non c'\xe9 corrispondenza", "iso-8859-1" },                                             /* it */
+	{ "\x1b$(B>e5i8!:w\x1b(B", "euc-jp" },                                                     /* ja */
+	{ "\x1b$(C0m1^\x1b(B \x1b$(C0K;v\x1b(B", "euc-kr" },                                       /* ko */
+	{ "I\xf0sami paie\xf0ka", "iso-8859-13" },                                                 /* lt */
+	{ "Papla\xf0in\xe2t\xe2 Mekl\xe7\xf0""ana", "iso-8859-13" },                               /* lv */
+	{ "Kopi\xebren", "iso-8859-15" },                                                          /* nl */
+	{ "\xd8ydelagd S\xf8k", "iso-8859-1" },                                                    /* nn */
+	{ "Avansert s\xf8k", "iso-8859-1" },                                                       /* no */
+	{ "\x1b-B\xacr\xf3""d\xb3""a\x1b-A ksi\x1b-B\xb1\xbfki\x1b-A adresowej", "iso-8859-2" },   /* pl */
+	{ "C\x1b-B\xe3utare\x1b-A avansat\x1b-B\xe3\x1b-A ", "iso-8859-2" },                       /* ro */
+	{ "\x1b-L\xc0\xd0\xe1\xe8\xd8\xe0\xd5\xdd\xdd\xeb\xd9\x1b-A \x1b-L\xdf\xde\xd8\xe1\xda\x1b-A ", "koi8-r" }, /* ru */
+	{ "Pokro\xc4\x8dil\xc3\xa9 h\xc4\xbe""adanie", "utf-8" },                                  /* sk */
+	{ "Ga \xc5\xbe""elite", "utf-8" },                                                         /* sl */
+	{ "den \xe4nd\xe5?", "iso-8859-1" },                                                       /* sv */
+	{ "Geli\x1b-M\xfemi\xfe\x1b-A Arama", "iso-8859-9" },                                      /* tr */
+	{ "\xf5\xc4\xcf\xd3\xcb\xcf\xce\xc1\xcc\xc5\xce\xc9\xca \xd0\xcf\xdb\xd5\xcb", "koi8-u" }, /* uk */
 	
 #if 0
 	/* this is expected to fail */
-	{ "ɚ尋(I>(B", "utf-8" },         /* zh_TW */
+	{ "\xe9\x92\xc9\x9a\x8e\xe5\xb0\x8b\xe6\x1b(I>\x1b(B", "utf-8" },                          /* zh_TW */
 #endif
 };
 
@@ -206,20 +134,13 @@ test_utils (void)
 
 int main (int argc, char **argv)
 {
-	g_mime_iconv_init ();
+	g_mime_init ();
 	
 	testsuite_init (argc, argv);
 	
-#ifdef TEST_CACHE
-	ZenTimerStart (NULL);
-	test_cache ();
-	ZenTimerStop (NULL);
-	ZenTimerReport (NULL, "test_cache()");
-#endif
-	
 	test_utils ();
 	
-	g_mime_iconv_shutdown ();
+	g_mime_shutdown ();
 	
 	return testsuite_exit ();
 }
